==> PySDM-2.6.tar.gz: PySDM-2.6/tests/smoke_tests/shipway_and_hill_2012/test_initial_condition.py <==
# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
import numpy as np
import pytest
from matplotlib import pyplot
from PySDM_examples.Shipway_and_Hill_2012 import Settings, Simulation

from PySDM.physics import si


class TestInitialCondition:
    @staticmethod
    @pytest.mark.parametrize(
        "params",
        (
            {},
            {"p0": 1002 * si.hPa, "particle_reservoir_depth": 0 * si.m},
            {"p0": 1014 * si.hPa, "particle_reservoir_depth": 100 * si.m},
            {"p0": 1027 * si.hPa, "particle_reservoir_depth": 200 * si.m},
            {"p0": 1040 * si.hPa, "particle_reservoir_depth": 300 * si.m},
        ),
    )
    def test_initial_condition(params, plot=False):
        # Arrange
        settings = Settings(
            n_sd_per_gridbox=100, rho_times_w_1=2 * si.m / si.s, **params
        )
        simulation = Simulation(settings)

        # Act
        output = simulation.run(nt=0)

        # Plot
        if plot:
            for var in ("RH", "T", "qv", "p"):
                pyplot.plot(output[var][:], output["z"], linestyle="--", marker="o")
                if var == "qv":
                    for value in (0.015, 0.0138, 0.0024):
                        pyplot.axvline(value)
                pyplot.ylabel("Z [m]")
                pyplot.xlabel(
                    var + " [" + simulation.particulator.products[var].unit + "]"
                )
                pyplot.grid()
                pyplot.show()

        # Assert
        for key in ("p", "T", "RH"):
            output[key] = output[key][
                int(settings.particle_reservoir_depth / settings.dz) :, 0
            ]
        assert output["RH"].shape == (int(settings.z_max // settings.dz),)

        assert 30 < np.amin(output["RH"]) < 46
        assert 99 < np.amax(output["RH"]) < 100

        assert 725 * si.hPa < np.amin(output["p"]) < 735 * si.hPa
        assert (np.diff(output["p"]) < 0).all()
        assert 1000 * si.hPa < np.amax(output["p"]) < 1005 * si.hPa

        assert 280 * si.K < np.amin(output["T"]) < 285 * si.K
        assert output["T"][0] > np.amin(output["T"])
        assert 295 * si.K < np.amax(output["T"]) < 300 * si.K

==> PySDM-2.7.tar.gz: PySDM-2.7/tests/smoke_tests/shipway_and_hill_2012/test_initial_condition.py <==
# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
import numpy as np
import pytest
from matplotlib import pyplot
from PySDM_examples.Shipway_and_Hill_2012 import Settings, Simulation

from PySDM.physics import si


class TestInitialCondition:
    @staticmethod
    @pytest.mark.parametrize(
        "particle_reservoir_depth",
        (
            0 * si.m,
            100 * si.m,
            200 * si.m,
            300 * si.m,
            400 * si.m,
            500 * si.m,
            1000 * si.m,
        ),
    )
    def test_initial_condition(particle_reservoir_depth, plot=False):
        # Arrange
        settings = Settings(
            n_sd_per_gridbox=100,
            rho_times_w_1=2 * si.m / si.s,
            particle_reservoir_depth=particle_reservoir_depth,
        )
        simulation = Simulation(settings)

        # Act
        output = simulation.run(nt=0)

        # Plot
        if plot:
            for var in ("RH", "T", "qv", "p"):
                pyplot.plot(output[var][:], output["z"], linestyle="--", marker="o")
                if var == "qv":
                    for value in (0.015, 0.0138, 0.0024):
                        pyplot.axvline(value)
                pyplot.ylabel("Z [m]")
                pyplot.title(f"reservoir depth: {particle_reservoir_depth} m")
                pyplot.xlabel(
                    var + " [" + simulation.particulator.products[var].unit + "]"
                )
                pyplot.grid()
                pyplot.show()

        # Assert
        for key in ("p", "T", "RH"):
            output[key] = output[key][
                int(settings.particle_reservoir_depth / settings.dz) :, 0
            ]
        assert output["RH"].shape == (int(settings.z_max // settings.dz),)

        assert 28 < np.amin(output["RH"]) < 32
        assert 96 < np.amax(output["RH"]) < 98

        assert 725 * si.hPa < np.amin(output["p"]) < 735 * si.hPa
        assert (np.diff(output["p"]) < 0).all()
        assert 1000 * si.hPa < np.amax(output["p"]) < 1010 * si.hPa

        assert 280 * si.K < np.amin(output["T"]) < 285 * si.K
        assert output["T"][0] > np.amin(output["T"])
        assert 295 * si.K < np.amax(output["T"]) < 300 * si.K
